﻿CREATE TABLE cesta (
  CestaID smallint(5) unsigned NOT NULL auto_increment,
  ClienteID smallint(5) unsigned NOT NULL default '0',
  FechaCreacion timestamp NOT NULL,
  TipoEnvio enum('Correo','Mensajer¡a') default NULL,
  MedioPago enum('Tarjeta','Cta.Cr?dito') default NULL,
  PRIMARY KEY  (CestaID),
  KEY FKI_Cesta (ClienteID),
  CONSTRAINT `0_46` FOREIGN KEY (`ClienteID`) REFERENCES `clientes` (`ClienteID`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;
CREATE TABLE clientes (
  ClienteID smallint(5) unsigned NOT NULL auto_increment,
  Nombre varchar(20) NOT NULL default '',
  Apellidos varchar(25) NOT NULL default '',
  EMail varchar(50) NOT NULL default '',
  PalabraPaso varchar(16) default NULL,
  AceptaCookies enum('S','N') default 'N',
  Suscriptor enum('S','N') default 'N',
  Direccion varchar(50) NOT NULL default '',
  Ciudad varchar(50) NOT NULL default '',
  Provincia varchar(50) default NULL,
  Pais varchar(50) NOT NULL default 'Espa¤a',
  CodigoPostal varchar(10) default NULL,
  Telefono varchar(20) default NULL,
  FAX varchar(20) default NULL,
  TipoTarjeta enum('VISA','MASTER','AMERICAN') default NULL,
  NumeroTarjeta varchar(20) default NULL,
  NombreEntarjeta varchar(50) default NULL,
  FechaCaducidad date default NULL,
  LimiteCredito decimal(10,2) unsigned default NULL,
  UltimaMod timestamp NOT NULL,
  FechaCreacion timestamp NOT NULL,
  PRIMARY KEY  (ClienteID)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;
CREATE TABLE departamentos (
  DepartamentoID smallint(5) unsigned NOT NULL auto_increment,
  DepartamentoRaizID smallint(5) unsigned NOT NULL default '0',
  Nombre varchar(50) NOT NULL default '',
  Imagen varchar(255) default NULL,
  PRIMARY KEY  (DepartamentoID)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;
CREATE TABLE itemcesta (
  ItemCestaID smallint(5) unsigned NOT NULL auto_increment,
  CestaID smallint(5) unsigned NOT NULL default '0',
  LibroID smallint(5) unsigned NOT NULL default '0',
  CantidadUnidades smallint(5) unsigned NOT NULL default '0',
  PRIMARY KEY  (ItemCestaID),
  KEY FKI_ItemCesta_Cesta (CestaID),
  KEY FKI_ItemCesta_Libro (LibroID),
  CONSTRAINT `0_49` FOREIGN KEY (`CestaID`) REFERENCES `cesta` (`CestaID`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;
CREATE TABLE itempedido (
  ItemPedidoID mediumint(8) unsigned NOT NULL auto_increment,
  PedidoID mediumint(8) unsigned NOT NULL default '0',
  LibroID char(13) NOT NULL default '',
  Unidades smallint(5) unsigned NOT NULL default '1',
  PesoTotal float(5,2) unsigned NOT NULL default '0.00',
  PrecioTotal decimal(12,2) unsigned NOT NULL default '0.00',
  IVATotal decimal(12,2) unsigned NOT NULL default '0.00',
  PrecioVP decimal(12,2) unsigned NOT NULL default '0.00',
  PRIMARY KEY  (ItemPedidoID),
  KEY FKI_ItemPedido_Libro (LibroID),
  KEY FKI_ItemPedido_Pedido (PedidoID),
  CONSTRAINT `0_61` FOREIGN KEY (`LibroID`) REFERENCES `libros` (`LibroID`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;
CREATE TABLE libros (
  LibroID varchar(13) NOT NULL default '',
  DepartamentoID smallint(5) unsigned NOT NULL default '0',
  Nombre varchar(200) NOT NULL default '',
  DetalleMenor varchar(200) NOT NULL default '',
  DetalleMayor blob,
  Autor text NOT NULL,
  Editorial varchar(100) NOT NULL default '',
  Paginas smallint(5) unsigned NOT NULL default '0',
  Cubierta enum('R£stica','Carton?','CD') default 'R£stica',
  Tema varchar(50) default NULL,
  Imagen varchar(255) default NULL,
  Peso float(5,2) unsigned NOT NULL default '0.00',
  Precio decimal(12,2) unsigned NOT NULL default '0.00',
  IVA decimal(12,2) unsigned NOT NULL default '0.00',
  Existencias mediumint(8) unsigned NOT NULL default '0',
  ProveedorID smallint(5) unsigned NOT NULL default '0',
  PRIMARY KEY  (LibroID)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;
CREATE TABLE pedidos (
  PedidoID mediumint(8) unsigned NOT NULL auto_increment,
  ClienteID smallint(5) unsigned NOT NULL default '0',
  FechaPedido date default NULL,
  Nombre varchar(20) NOT NULL default '',
  Apellidos varchar(25) NOT NULL default '',
  EMail varchar(50) NOT NULL default '',
  Direccion varchar(50) NOT NULL default '',
  Ciudad varchar(50) NOT NULL default '',
  Provincia varchar(50) default NULL,
  Pais varchar(50) default NULL,
  CodigoPostal varchar(10) default NULL,
  Telefono varchar(20) default NULL,
  FAX varchar(20) default NULL,
  TipoTarjeta enum('VISA','MASTER','AMERICAN') default NULL,
  NumeroTarjeta varchar(20) default NULL,
  NombreEntarjeta varchar(50) default NULL,
  FechaCaducidad date default NULL,
  TipoEnvio enum('Correo','Mensajer¡a') default 'Correo',
  MedioPago enum('Tarjeta','Cta.Cr?dito') default NULL,
  PesoEnvio float(5,2) unsigned NOT NULL default '0.00',
  GastosEnvio decimal(12,2) unsigned NOT NULL default '0.00',
  PrecioSinIVA decimal(12,2) unsigned NOT NULL default '0.00',
  IVA decimal(12,2) unsigned NOT NULL default '0.00',
  TotalCargo decimal(12,2) unsigned NOT NULL default '0.00',
  Estado set('En proceso','Suspendido','Espera existencias','Faltan existencias','Impagado','Pagado','Enviado','Entregado','Cancelado') default NULL,
  FechaEstado date default NULL,
  FechaEnvio date default NULL,
  RefEnvio varchar(255) default NULL,
  PRIMARY KEY  (PedidoID),
  KEY FKI_Pedidos (ClienteID),
  CONSTRAINT `0_58` FOREIGN KEY (`ClienteID`) REFERENCES `clientes` (`ClienteID`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;
CREATE TABLE proveedores (
  ProveedorID smallint(5) unsigned NOT NULL auto_increment,
  Nombre varchar(20) NOT NULL default '',
  Apellidos varchar(25) NOT NULL default '',
  Empresa varchar(50) NOT NULL default '',
  EMail varchar(50) NOT NULL default '',
  PRIMARY KEY  (ProveedorID)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;

